from flask import request, jsonify, g, current_app
from flask_restx import Resource, Namespace, reqparse
from sqlalchemy import select
from sqlalchemy.orm import Session

from app.defines import StatesCode
from app.modle.menus import Menus
from app.modle.role import Role
from app.modle.users import User
from app.utils.jwt_util import login_required

ns = Namespace('permission', description='权限管理')


@ns.route('/permission')
class PermissionApi(Resource):
    method_decorators = [login_required]

    @ns.doc(id='get_permission', description='获取权限配置信息')
    @ns.expect()
    def get(self):
        """获取权限信息"""
        data = []
        with Session(current_app.engine) as session:
            stmt = select(Menus.id, Menus.name).where(Menus.parent_id == 0)
            results = session.execute(stmt)
            for result in results:
                stmt2 = select(Menus.id, Menus.name).where(Menus.parent_id == result.id)
                data.append(
                    {
                        'id': result.id,
                        'name': result.name,
                        'children': [
                            {'id': result1.id, 'name': result1.name} for result1 in session.execute(stmt2)
                        ]
                    }
                )

        return jsonify(code=StatesCode.SUCCESS, message='成功', data=data)


auth_permission = reqparse.RequestParser(bundle_errors=True)
auth_permission.add_argument(name='path', type=str, location='args', required=False, help='请求url')


@ns.route('/auth_permission')
class AuthPermissionApi(Resource):
    method_decorators = [login_required]

    @ns.doc(id='auth_permission', description='权限认证')
    @ns.expect(auth_permission)
    def get(self):
        """权限认证"""
        path = request.args.get('path')

        with Session(current_app.engine) as session:
            # 根据用户id获取角色id
            stmt = select(User.role).where(User.id == g.user_id)
            role_id = session.execute(stmt).scalars().first()
            # 根据角色id获取权限id
            stmt = select(Role.role_permission).where(Role.id == role_id)
            role_permission = session.execute(stmt).scalars().first()
            # 根据权限id获取可访问的接口
            stmt = select(Menus.router).where(Menus.id.in_(role_permission))
            results = session.execute(stmt).scalars().all()
            # 判断传入接口是否在可访问的接口中
            if path not in results:
                return jsonify(code=StatesCode.UNKNOWN_ERROR, message='无权限')
