from sqlalchemy import String, Column, Integer, Float

from app.modle import Base


class Template(Base):
    """模版表"""

    __tablename__ = 'template'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=False, unique=False, index=False, doc='模版名称')
    format = Column(String, nullable=True, unique=False, index=False, doc='模版格式')
    report_type = Column(String, nullable=True, unique=False, index=False, doc='报告类型')
    introduction = Column(String, nullable=True, unique=False, index=False, doc='模版简介')
    creator = Column(String, nullable=True, unique=False, index=False, doc='创建者')
    create_time = Column(String, nullable=True, unique=False, index=False, doc='创建时间')
    update_time = Column(String, nullable=True, unique=False, index=False, doc='修改时间')
    template_url = Column(String, nullable=True, unique=False, index=False, doc='模版存储地址')
    template_type = Column(String, nullable=True, unique=False, index=False, doc='模版类型')


class CompanyData(Base):
    """公司基本信息"""

    __tablename__ = 'company_data'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    management_unit = Column(String, nullable=True, unique=False, index=False, doc='管理单位')
    custodian_unit = Column(String, nullable=True, unique=False, index=False, doc='托管单位')
    introduction = Column(String, nullable=True, unique=False, index=False, doc='公司简介')
    contact_person = Column(String, nullable=True, unique=False, index=False, doc='联系人')
    contact_information = Column(String, nullable=True, unique=False, index=False, doc='联系人方式')
    picture = Column(String, nullable=True, unique=False, index=False, doc='公司图片url')


class Building(Base):
    """楼宇基本信息"""

    __tablename__ = 'building'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=True, unique=False, index=False, doc='楼宇名称')
    area = Column(Float, nullable=True, unique=False, index=False, doc='楼宇面积')
    floor = Column(String, nullable=True, unique=False, index=False, doc='建筑楼层')
    trem = Column(String, nullable=True, unique=False, index=False, doc='建筑年限')
    date = Column(String, nullable=True, unique=False, index=False, doc='建成日期')
    contact_person = Column(String, nullable=True, unique=False, index=False, doc='联系人')
    contact_information = Column(String, nullable=True, unique=False, index=False, doc='联系人方式')
    introduction = Column(String, nullable=True, unique=False, index=False, doc='楼宇简介')
    picture = Column(String, nullable=True, unique=False, index=False, doc='楼宇图片url')


class UnderlyingSystem(Base):
    """底层系统信息"""

    __tablename__ = 'underlying_system'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    picture = Column(String, nullable=True, unique=False, index=False, doc='图片url')
